==> mingw-w64-clang-aarch64-qt6-static-6.7.0-1-any.pkg.tar.zst: clangarm64/qt6-static/lib/cmake/Qt6Qml/QmlPlugins/Qt6qtvkbbuiltinstylespluginTargets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "Qt6::qtvkbbuiltinstylesplugin" for configuration "Release"
set_property(TARGET Qt6::qtvkbbuiltinstylesplugin APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::qtvkbbuiltinstylesplugin PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/share/qt6/qml/QtQuick/VirtualKeyboard/Styles/Builtin/libqtvkbbuiltinstylesplugin.a"
  )

list(APPEND _cmake_import_check_targets Qt6::qtvkbbuiltinstylesplugin )
list(APPEND _cmake_import_check_files_for_Qt6::qtvkbbuiltinstylesplugin "${_IMPORT_PREFIX}/share/qt6/qml/QtQuick/VirtualKeyboard/Styles/Builtin/libqtvkbbuiltinstylesplugin.a" )

# Import target "Qt6::qtvkbbuiltinstylesplugin_resources_1" for configuration "Release"
set_property(TARGET Qt6::qtvkbbuiltinstylesplugin_resources_1 APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::qtvkbbuiltinstylesplugin_resources_1 PROPERTIES
  IMPORTED_COMMON_LANGUAGE_RUNTIME_RELEASE ""
  IMPORTED_OBJECTS_RELEASE "${_IMPORT_PREFIX}/share/qt6/qml/QtQuick/VirtualKeyboard/Styles/Builtin/objects-Release/qtvkbbuiltinstylesplugin_resources_1/.rcc/qrc_qmake_QtQuick_VirtualKeyboard_Styles_Builtin_init.cpp.obj"
  )

list(APPEND _cmake_import_check_targets Qt6::qtvkbbuiltinstylesplugin_resources_1 )
list(APPEND _cmake_import_check_files_for_Qt6::qtvkbbuiltinstylesplugin_resources_1 "${_IMPORT_PREFIX}/share/qt6/qml/QtQuick/VirtualKeyboard/Styles/Builtin/objects-Release/qtvkbbuiltinstylesplugin_resources_1/.rcc/qrc_qmake_QtQuick_VirtualKeyboard_Styles_Builtin_init.cpp.obj" )

# Import target "Qt6::qtvkbbuiltinstylesplugin_init" for configuration "Release"
set_property(TARGET Qt6::qtvkbbuiltinstylesplugin_init APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::qtvkbbuiltinstylesplugin_init PROPERTIES
  IMPORTED_COMMON_LANGUAGE_RUNTIME_RELEASE ""
  IMPORTED_OBJECTS_RELEASE "${_IMPORT_PREFIX}/share/qt6/qml/QtQuick/VirtualKeyboard/Styles/Builtin/objects-Release/qtvkbbuiltinstylesplugin_init/qtvkbbuiltinstylesplugin_init.cpp.obj"
  )

list(APPEND _cmake_import_check_targets Qt6::qtvkbbuiltinstylesplugin_init )
list(APPEND _cmake_import_check_files_for_Qt6::qtvkbbuiltinstylesplugin_init "${_IMPORT_PREFIX}/share/qt6/qml/QtQuick/VirtualKeyboard/Styles/Builtin/objects-Release/qtvkbbuiltinstylesplugin_init/qtvkbbuiltinstylesplugin_init.cpp.obj" )

# Import target "Qt6::qtvkbbuiltinstylesplugin_resources_2" for configuration "Release"
set_property(TARGET Qt6::qtvkbbuiltinstylesplugin_resources_2 APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::qtvkbbuiltinstylesplugin_resources_2 PROPERTIES
  IMPORTED_COMMON_LANGUAGE_RUNTIME_RELEASE ""
  IMPORTED_OBJECTS_RELEASE "${_IMPORT_PREFIX}/lib/objects-Release/qtvkbbuiltinstylesplugin_resources_2/.rcc/qrc_virtualkeyboard_default_style_init.cpp.obj"
  )

list(APPEND _cmake_import_check_targets Qt6::qtvkbbuiltinstylesplugin_resources_2 )
list(APPEND _cmake_import_check_files_for_Qt6::qtvkbbuiltinstylesplugin_resources_2 "${_IMPORT_PREFIX}/lib/objects-Release/qtvkbbuiltinstylesplugin_resources_2/.rcc/qrc_virtualkeyboard_default_style_init.cpp.obj" )

# Import target "Qt6::qtvkbbuiltinstylesplugin_resources_3" for configuration "Release"
set_property(TARGET Qt6::qtvkbbuiltinstylesplugin_resources_3 APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::qtvkbbuiltinstylesplugin_resources_3 PROPERTIES
  IMPORTED_COMMON_LANGUAGE_RUNTIME_RELEASE ""
  IMPORTED_OBJECTS_RELEASE "${_IMPORT_PREFIX}/lib/objects-Release/qtvkbbuiltinstylesplugin_resources_3/.rcc/qrc_virtualkeyboard_retro_style_init.cpp.obj"
  )

list(APPEND _cmake_import_check_targets Qt6::qtvkbbuiltinstylesplugin_resources_3 )
list(APPEND _cmake_import_check_files_for_Qt6::qtvkbbuiltinstylesplugin_resources_3 "${_IMPORT_PREFIX}/lib/objects-Release/qtvkbbuiltinstylesplugin_resources_3/.rcc/qrc_virtualkeyboard_retro_style_init.cpp.obj" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)

==> mingw-w64-clang-aarch64-qt6-static-6.10.1-1-any.pkg.tar.zst: clangarm64/qt6-static/lib/cmake/Qt6Qml/QmlPlugins/Qt6qtvkbbuiltinstylespluginTargets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "Qt6::qtvkbbuiltinstylesplugin" for configuration "Release"
set_property(TARGET Qt6::qtvkbbuiltinstylesplugin APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::qtvkbbuiltinstylesplugin PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/share/qt6/qml/QtQuick/VirtualKeyboard/Styles/Builtin/libqtvkbbuiltinstylesplugin.a"
  )

list(APPEND _cmake_import_check_targets Qt6::qtvkbbuiltinstylesplugin )
list(APPEND _cmake_import_check_files_for_Qt6::qtvkbbuiltinstylesplugin "${_IMPORT_PREFIX}/share/qt6/qml/QtQuick/VirtualKeyboard/Styles/Builtin/libqtvkbbuiltinstylesplugin.a" )

# Import target "Qt6::qtvkbbuiltinstylesplugin_resources_1" for configuration "Release"
set_property(TARGET Qt6::qtvkbbuiltinstylesplugin_resources_1 APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::qtvkbbuiltinstylesplugin_resources_1 PROPERTIES
  IMPORTED_COMMON_LANGUAGE_RUNTIME_RELEASE ""
  IMPORTED_OBJECTS_RELEASE "${_IMPORT_PREFIX}/share/qt6/qml/QtQuick/VirtualKeyboard/Styles/Builtin/objects-Release/qtvkbbuiltinstylesplugin_resources_1/.qt/rcc/qrc_qmake_QtQuick_VirtualKeyboard_Styles_Builtin_init.cpp.obj"
  )

list(APPEND _cmake_import_check_targets Qt6::qtvkbbuiltinstylesplugin_resources_1 )
list(APPEND _cmake_import_check_files_for_Qt6::qtvkbbuiltinstylesplugin_resources_1 "${_IMPORT_PREFIX}/share/qt6/qml/QtQuick/VirtualKeyboard/Styles/Builtin/objects-Release/qtvkbbuiltinstylesplugin_resources_1/.qt/rcc/qrc_qmake_QtQuick_VirtualKeyboard_Styles_Builtin_init.cpp.obj" )

# Import target "Qt6::qtvkbbuiltinstylesplugin_init" for configuration "Release"
set_property(TARGET Qt6::qtvkbbuiltinstylesplugin_init APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::qtvkbbuiltinstylesplugin_init PROPERTIES
  IMPORTED_COMMON_LANGUAGE_RUNTIME_RELEASE ""
  IMPORTED_OBJECTS_RELEASE "${_IMPORT_PREFIX}/share/qt6/qml/QtQuick/VirtualKeyboard/Styles/Builtin/objects-Release/qtvkbbuiltinstylesplugin_init/qtvkbbuiltinstylesplugin_init.cpp.obj"
  )

list(APPEND _cmake_import_check_targets Qt6::qtvkbbuiltinstylesplugin_init )
list(APPEND _cmake_import_check_files_for_Qt6::qtvkbbuiltinstylesplugin_init "${_IMPORT_PREFIX}/share/qt6/qml/QtQuick/VirtualKeyboard/Styles/Builtin/objects-Release/qtvkbbuiltinstylesplugin_init/qtvkbbuiltinstylesplugin_init.cpp.obj" )

# Import target "Qt6::qtvkbbuiltinstylesplugin_resources_2" for configuration "Release"
set_property(TARGET Qt6::qtvkbbuiltinstylesplugin_resources_2 APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::qtvkbbuiltinstylesplugin_resources_2 PROPERTIES
  IMPORTED_COMMON_LANGUAGE_RUNTIME_RELEASE ""
  IMPORTED_OBJECTS_RELEASE "${_IMPORT_PREFIX}/lib/objects-Release/qtvkbbuiltinstylesplugin_resources_2/.qt/rcc/qrc_virtualkeyboard_default_style_init.cpp.obj"
  )

list(APPEND _cmake_import_check_targets Qt6::qtvkbbuiltinstylesplugin_resources_2 )
list(APPEND _cmake_import_check_files_for_Qt6::qtvkbbuiltinstylesplugin_resources_2 "${_IMPORT_PREFIX}/lib/objects-Release/qtvkbbuiltinstylesplugin_resources_2/.qt/rcc/qrc_virtualkeyboard_default_style_init.cpp.obj" )

# Import target "Qt6::qtvkbbuiltinstylesplugin_resources_3" for configuration "Release"
set_property(TARGET Qt6::qtvkbbuiltinstylesplugin_resources_3 APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::qtvkbbuiltinstylesplugin_resources_3 PROPERTIES
  IMPORTED_COMMON_LANGUAGE_RUNTIME_RELEASE ""
  IMPORTED_OBJECTS_RELEASE "${_IMPORT_PREFIX}/lib/objects-Release/qtvkbbuiltinstylesplugin_resources_3/.qt/rcc/qrc_virtualkeyboard_retro_style_init.cpp.obj"
  )

list(APPEND _cmake_import_check_targets Qt6::qtvkbbuiltinstylesplugin_resources_3 )
list(APPEND _cmake_import_check_files_for_Qt6::qtvkbbuiltinstylesplugin_resources_3 "${_IMPORT_PREFIX}/lib/objects-Release/qtvkbbuiltinstylesplugin_resources_3/.qt/rcc/qrc_virtualkeyboard_retro_style_init.cpp.obj" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
